@@ -1,11 +1,11 @@
-import logging
+from openshift.dynamic.exceptions import NotFoundError
 
-from ocp_resources.constants import NOT_FOUND_ERROR_EXCEPTION_DICT
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 
 
-LOGGER = logging.getLogger(__name__)
+LOGGER = get_logger(name=__name__)
 
 
 class Benchmark(NamespacedResource):
@@ -43,7 +43,7 @@ class Benchmark(NamespacedResource):
             wait_timeout=30,
             sleep=1,
             func=lambda: getattr(self.instance, parent, None),
-            exceptions_dict=NOT_FOUND_ERROR_EXCEPTION_DICT,
+            exceptions=NotFoundError,
         )
         for sample in samples:
             if sample:
