@@ -1,9 +1,8 @@
-import logging
-
+from ocp_resources.logger import get_logger
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-LOGGER = logging.getLogger(__name__)
+LOGGER = get_logger(name=__name__)
 
 
 def _get_status_condition_log_message(**status_condition):
@@ -26,8 +25,6 @@ class MTV:
         Migration
         StorageMap
         NetworkMap
-        Host
-        ForkliftController
     """
 
     def __init__(self):
@@ -55,11 +52,9 @@ class MTV:
         STORAGE_MAP_READY = "The storage map is ready."
         PLAN_READY = "The migration plan is ready."
         PLAN_SUCCEEDED = "The plan execution has SUCCEEDED."
-        PLAN_FAILED = "The plan execution has FAILED."
         MIGRATION_READY = "The migration is ready."
         MIGRATION_RUNNING = "The migration is RUNNING"
         MIGRATION_SUCCEEDED = "The migration has SUCCEEDED."
-        HOST_READY = "The host is ready."
 
     class ProviderType:
         VSPHERE = "vsphere"
@@ -92,7 +87,7 @@ class MTV:
         samples = TimeoutSampler(
             wait_timeout=wait_timeout,
             sleep=1,
-            func=self.api.get,
+            func=self.api().get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -132,20 +127,18 @@ class MTV:
             )
             raise
 
-    def wait_for_condition_ready(self, wait_timeout=360):
+    def wait_for_condition_ready(self):
         self.wait_for_resource_status(
             condition_message=self.condition_message_ready,
             condition_status=self.Condition.Status.TRUE,
             condition_type=self.Condition.READY,
-            wait_timeout=wait_timeout,
         )
 
-    def wait_for_condition_succeeded(self, wait_timeout=600):
+    def wait_for_condition_succeeded(self):
         self.wait_for_resource_status(
             condition_type=self.Status.SUCCEEDED,
             condition_message=self.condition_message_succeeded,
             condition_status=self.Condition.Status.TRUE,
-            wait_timeout=wait_timeout,
         )
 
     @property
