@@ -1,7 +1,13 @@
-from ocp_resources.constants import TIMEOUT_4MINUTES
+from ocp_resources.logger import get_logger
 from ocp_resources.resource import Resource
 
 
+LOGGER = get_logger(name=__name__)
+
+_DELETE_NUDGE_DELAY = 30
+_DELETE_NUDGE_INTERVAL = 5
+
+
 class Namespace(Resource):
     """
     Namespace object, inherited from Resource.
@@ -14,29 +20,16 @@ class Namespace(Resource):
 
     def __init__(
         self,
-        name=None,
+        name,
         client=None,
         teardown=True,
         label=None,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
     ):
-        super().__init__(
-            name=name,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
-        )
+        super().__init__(name=name, client=client, teardown=teardown)
         self.label = label
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         if self.label:
             res.setdefault("metadata", {}).setdefault("labels", {}).update(self.label)
         return res
